*-------------------------------------------------------------------------*
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03404
 |       DRUG ABUSE TREATMENT OUTCOME STUDY--ADOLESCENT (DATOS-A),
 |                       1993-1995: [UNITED STATES]
 |         (DATASET 0009:  12-MONTH FOLLOW-UP URINE RESULT DATA)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03404-0009-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 *------------------------------------------------------------------------;

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE caseid    -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE' ;
  VALUE amph      -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
  VALUE barb      -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
  VALUE benz      -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
  VALUE cann      -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
  VALUE coc       -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
  VALUE meth      -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
  VALUE op        -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
  VALUE phen      -9='LEGITIMATE NONRESPONSE' -8='MISSING' -7='REFUSAL'
                  -6='MULTIPLE RESPONSE' -5='BAD DATA' -4='DON''T KNOW'
                  -3='NOT APPLICABLE' -2='RESPONSE ILLEGIBLE'
                  0='(0) NEGATIVE FOR DRUG' 1='(1) POSITIVE FOR DRUG' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=24;
INPUT
        CASEID 1-8              AMPH 9-10               BARB 11-12
        BENZ 13-14              CANN 15-16              COC 17-18
        METH 19-20              OP 21-22                PHEN 23-24
        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   AMPH    = 'AMPHETAMINE TEST RESULT'
   BARB    = 'BARBITURATES TEST RESULT'
   BENZ    = 'BENZODIAZEPINES TEST RESULT'
   CANN    = 'CANNABINOID TEST RESULT'
   COC     = 'COCAINE TEST RESULT'
   METH    = 'METHAQUALONES TEST RESULT'
   OP      = 'OPIATES TEST RESULT'
   PHEN    = 'PHENCYCLIDINE TEST RESULT'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -1) THEN CASEID = .;
   IF (AMPH <= -1) THEN AMPH = .;
   IF (BARB <= -1) THEN BARB = .;
   IF (BENZ <= -1) THEN BENZ = .;
   IF (CANN <= -1) THEN CANN = .;
   IF (COC <= -1) THEN COC = .;
   IF (METH <= -1) THEN METH = .;
   IF (OP <= -1) THEN OP = .;
   IF (PHEN <= -1) THEN PHEN = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CASEID caseid. AMPH amph. BARB barb.
         BENZ benz. CANN cann. COC coc.
         METH meth. OP op. PHEN phen.
          ;
*/

RUN ;
